ADJECTIVES = [
    "able",
    "above",
    "absent",
    "absolute",
    "abstract",
    "abundant",
    "academic",
    "acceptable",
    "accessible",
    "active",
    "actual",
    "acute",
    "adaptable",
    "adept",
    "adequate",
    "adjacent",
    "admirable",
    "advanced",
    "aesthetic",
    "affable",
    "afraid",
    "agile",
    "agreeable",
    "alien",
    "alive",
    "all",
    "alleged",
    "allied",
    "alone",
    "alright",
    "amazing",
    "ambitious",
    "ample",
    "amused",
    "ancient",
    "angry",
    "animated",
    "annoyed",
    "annual",
    "anonymous",
    "anxious",
    "apparent",
    "apt",
    "arctic",
    "arid",
    "artistic",
    "ashamed",
    "aspiring",
    "athletic",
    "attached",
    "attentive",
    "attractive",
    "authentic",
    "average",
    "awake",
    "aware",
    "awesome",
    "awful",
    "awkward",
    "baby",
    "back",
    "bad",
    "balanced",
    "bare",
    "basic",
    "beautiful",
    "best",
    "better",
    "big",
    "bitter",
    "black",
    "blue",
    "bold",
    "brave",
    "brief",
    "bright",
    "brilliant",
    "broken",
    "brown",
    "busy",
    "calm",
    "careful",
    "casual",
    "charming",
    "cheap",
    "cheerful",
    "choice",
    "civil",
    "classic",
    "clean",
    "clear",
    "clever",
    "close",
    "closed",
    "cloudy",
    "cold",
    "colorful",
    "common",
    "complete",
    "complex",
    "constant",
    "content",
    "cool",
    "correct",
    "crazy",
    "creative",
    "creepy",
    "critical",
    "crucial",
    "cruel",
    "curious",
    "curly",
    "current",
    "cute",
    "daily",
    "damaged",
    "damp",
    "dance",
    "dangerous",
    "dark",
    "dead",
    "dear",
    "decent",
    "decisive",
    "deep",
    "defiant",
    "delicate",
    "delicious",
    "delightful",
    "dense",
    "direct",
    "discrete",
    "distinct",
    "diverse",
    "divine",
    "dominant",
    "double",
    "dry",
    "dummy",
    "eager",
    "early",
    "earthy",
    "east",
    "eastern",
    "easy",
    "elegant",
    "empty",
    "endless",
    "entire",
    "equal",
    "essential",
    "eternal",
    "ethical",
    "exact",
    "excited",
    "exotic",
    "expert",
    "extra",
    "faint",
    "fair",
    "faithful",
    "false",
    "familiar",
    "famous",
    "fancy",
    "fast",
    "fat",
    "fatal",
    "fearless",
    "female",
    "feral",
    "fierce",
    "final",
    "fine",
    "firm",
    "first",
    "fit",
    "fixed",
    "flat",
    "flawed",
    "flexible",
    "fluffy",
    "fluent",
    "flying",
    "fond",
    "foolish",
    "formal",
    "free",
    "fresh",
    "friendly",
    "front",
    "frozen",
    "full",
    "fun",
    "funny",
    "future",
    "fuzzy",
    "game",
    "general",
    "gentle",
    "giant",
    "gifted",
    "giving",
    "glad",
    "global",
    "glorious",
    "golden",
    "good",
    "gorgeous",
    "grand",
    "grateful",
    "gray",
    "great",
    "green",
    "grey",
    "groovy",
    "gross",
    "growing",
    "guilty",
    "hairy",
    "handy",
    "happy",
    "hard",
    "harsh",
    "healthy",
    "heavy",
    "helpful",
    "hidden",
    "high",
    "holy",
    "honest",
    "hopeful",
    "hot",
    "huge",
    "human",
    "humble",
    "hungry",
    "ideal",
    "idle",
    "ill",
    "illegal",
    "immense",
    "immune",
    "impartial",
    "impolite",
    "important",
    "impossible",
    "impressive",
    "improper",
    "impulsive",
    "inch",
    "incorrect",
    "independent",
    "indoor",
    "industrial",
    "infinite",
    "informal",
    "initial",
    "injured",
    "inner",
    "innocent",
    "insane",
    "instant",
    "intense",
    "intent",
    "internal",
    "intimate",
    "invalid",
    "joint",
    "jolly",
    "joyful",
    "juicy",
    "jumping",
    "just",
    "keen",
    "kind",
    "known",
    "large",
    "last",
    "late",
    "lazy",
    "leading",
    "lean",
    "legal",
    "level",
    "light",
    "likely",
    "limited",
    "limp",
    "linear",
    "little",
    "lively",
    "living",
    "local",
    "logical",
    "lonely",
    "long",
    "loose",
    "lost",
    "loud",
    "lovely",
    "low",
    "loyal",
    "lucky",
    "mad",
    "magic",
    "magnetic",
    "main",
    "major",
    "male",
    "mammoth",
    "many",
    "massive",
    "master",
    "mature",
    "mean",
    "mega",
    "mellow",
    "mental",
    "merry",
    "messy",
    "micro",
    "mid",
    "middle",
    "mighty",
    "mild",
    "mini",
    "minor",
    "mint",
    "minute",
    "modern",
    "modest",
    "moral",
    "more",
    "most",
    "motionless",
    "mounted",
    "moving",
    "muddy",
    "mute",
    "mutual",
    "mysterious",
    "naive",
    "narrow",
    "native",
    "natural",
    "near",
    "neat",
    "necessary",
    "negative",
    "nervous",
    "neutral",
    "new",
    "next",
    "nice",
    "nimble",
    "noble",
    "noisy",
    "normal",
    "northern",
    "novel",
    "nuclear",
    "number",
    "numerous",
    "objective",
    "obliging",
    "obscure",
    "odd",
    "off",
    "old",
    "on",
    "only",
    "open",
    "optical",
    "optimal",
    "optimistic",
    "orange",
    "organic",
    "original",
    "other",
    "outer",
    "outgoing",
    "outside",
    "outstanding",
    "over",
    "painful",
    "pale",
    "parallel",
    "partial",
    "past",
    "patient",
    "peaceful",
    "perfect",
    "periodic",
    "personal",
    "physical",
    "plain",
    "plastic",
    "pleasant",
    "pleased",
    "polite",
    "poor",
    "popular",
    "positive",
    "possible",
    "potent",
    "powerful",
    "practical",
    "precious",
    "precise",
    "premium",
    "present",
    "pretty",
    "primary",
    "prime",
    "prior",
    "private",
    "pro",
    "probable",
    "productive",
    "profound",
    "proper",
    "proud",
    "public",
    "pure",
    "purple",
    "quaint",
    "quick",
    "quiet",
    "radical",
    "random",
    "rapid",
    "rare",
    "rational",
    "raw",
    "ready",
    "real",
    "rear",
    "red",
    "regular",
    "related",
    "relative",
    "relaxed",
    "relevant",
    "remote",
    "renewed",
    "rich",
    "right",
    "rigid",
    "ripe",
    "rising",
    "robust",
    "romantic",
    "rotten",
    "rough",
    "round",
    "royal",
    "rude",
    "ruling",
    "rural",
    "sacred",
    "sad",
    "safe",
    "salty",
    "same",
    "sane",
    "saving",
    "scary",
    "scientific",
    "screen",
    "secret",
    "secure",
    "select",
    "senior",
    "separate",
    "serious",
    "severe",
    "sexual",
    "shallow",
    "sharp",
    "sheer",
    "shiny",
    "short",
    "shy",
    "sick",
    "silent",
    "silky",
    "silly",
    "simple",
    "single",
    "skilled",
    "skinny",
    "sleek",
    "sleepy",
    "slight",
    "slim",
    "slow",
    "sly",
    "small",
    "smart",
    "smooth",
    "social",
    "soft",
    "solar",
    "sole",
    "solid",
    "solo",
    "sour",
    "southern",
    "spare",
    "sparkling",
    "special",
    "specific",
    "speedy",
    "spicy",
    "spiritual",
    "splendid",
    "square",
    "stable",
    "standard",
    "star",
    "stark",
    "static",
    "steady",
    "steep",
    "sticky",
    "stiff",
    "still",
    "stock",
    "stormy",
    "straight",
    "strange",
    "strict",
    "strong",
    "stupid",
    "subtle",
    "successful",
    "sudden",
    "sufficient",
    "suitable",
    "sunny",
    "super",
    "superb",
    "superior",
    "supporting",
    "supreme",
    "sure",
    "surprised",
    "sweet",
    "swift",
    "tall",
    "tame",
    "tart",
    "tepid",
    "terrible",
    "testing",
    "thick",
    "thin",
    "thirsty",
    "thoughtful",
    "tight",
    "tiny",
    "tired",
    "top",
    "total",
    "tough",
    "toxic",
    "true",
    "trusty",
    "ultimate",
    "unable",
    "unaware",
    "uncertain",
    "unchanged",
    "uncle",
    "uncommon",
    "unconscious",
    "under",
    "uneven",
    "unfair",
    "unfit",
    "unified",
    "unique",
    "united",
    "universal",
    "unknown",
    "unlikely",
    "unnatural",
    "unpleasant",
    "unreal",
    "unsafe",
    "unusual",
    "up",
    "upper",
    "upright",
    "upset",
    "urban",
    "urgent",
    "used",
    "useful",
    "useless",
    "usual",
    "vacant",
    "vague",
    "vain",
    "valid",
    "vast",
    "vertical",
    "very",
    "veteran",
    "viable",
    "vibrant",
    "vice",
    "vital",
    "vivid",
    "vocal",
    "void",
    "waiting",
    "walking",
    "warm",
    "warning",
    "wary",
    "waste",
    "weak",
    "wealthy",
    "wee",
    "weird",
    "welcome",
    "well",
    "west",
    "western",
    "wet",
    "what",
    "whole",
    "wide",
    "wild",
    "willing",
    "wise",
    "witty",
    "wonderful",
    "working",
    "worldly",
    "worn",
    "worried",
    "worthy",
    "wrong",
    "yellow",
    "young",
    "yummy",
]

ANIMALS = [
    "aardvark",
    "albatross",
    "alligator",
    "alpaca",
    "ant",
    "anteater",
    "antelope",
    "ape",
    "armadillo",
    "badger",
    "barracuda",
    "bat",
    "bear",
    "beaver",
    "bee",
    "bison",
    "boar",
    "buffalo",
    "butterfly",
    "camel",
    "capybara",
    "caribou",
    "cat",
    "caterpillar",
    "cattle",
    "chamois",
    "cheetah",
    "chicken",
    "chimpanzee",
    "chinchilla",
    "clam",
    "cobra",
    "cockroach",
    "cod",
    "cormorant",
    "coyote",
    "crab",
    "crane",
    "crocodile",
    "crow",
    "curlew",
    "deer",
    "dinosaur",
    "dog",
    "dogfish",
    "dolphin",
    "donkey",
    "dotterel",
    "dove",
    "dragonfly",
    "duck",
    "dugong",
    "dunlin",
    "eagle",
    "echidna",
    "eel",
    "eland",
    "elephant",
    "elk",
    "emu",
    "falcon",
    "ferret",
    "finch",
    "fish",
    "flamingo",
    "fly",
    "fox",
    "frog",
    "gaur",
    "gazelle",
    "gerbil",
    "giraffe",
    "gnat",
    "gnu",
    "goat",
    "goldfinch",
    "goldfish",
    "goose",
    "gorilla",
    "goshawk",
    "grasshopper",
    "grouse",
    "guanaco",
    "gull",
    "hamster",
    "hare",
    "hawk",
    "hedgehog",
    "heron",
    "herring",
    "hippo",
    "hornet",
    "horse",
    "human",
    "hummingbird",
    "hyena",
    "ibex",
    "ibis",
    "jackal",
    "jaguar",
    "jay",
    "jellyfish",
    "kangaroo",
    "kingfisher",
    "koala",
    "kookaburra",
    "kouprey",
    "kudu",
    "lapwing",
    "lark",
    "lemur",
    "leopard",
    "lion",
    "llama",
    "lobster",
    "locust",
    "loris",
    "louse",
    "lyrebird",
    "magpie",
    "mallard",
    "manatee",
    "mandrill",
    "mantis",
    "marten",
    "meerkat",
    "mink",
    "mole",
    "mongoose",
    "monkey",
    "moose",
    "mosquito",
    "mouse",
    "mule",
    "narwhal",
    "newt",
    "nightingale",
    "octopus",
    "okapi",
    "opossum",
    "oryx",
    "ostrich",
    "otter",
    "owl",
    "oyster",
    "panther",
    "parrot",
    "partridge",
    "peafowl",
    "pelican",
    "penguin",
    "pheasant",
    "pig",
    "pigeon",
    "pony",
    "porcupine",
    "porpoise",
    "quail",
    "quelea",
    "quetzal",
    "rabbit",
    "raccoon",
    "rail",
    "ram",
    "rat",
    "raven",
    "reddeer",
    "redpanda",
    "reindeer",
    "rhino",
    "rook",
    "salamander",
    "salmon",
    "sanddollar",
    "sandpiper",
    "sardine",
    "scorpion",
    "seahorse",
    "seal",
    "shark",
    "sheep",
    "shrew",
    "skunk",
    "snail",
    "snake",
    "sparrow",
    "spider",
    "spoonbill",
    "squid",
    "squirrel",
    "starling",
    "stingray",
    "stinkbug",
    "stork",
    "swallow",
    "swan",
    "tapir",
    "tarsier",
    "termite",
    "tiger",
    "toad",
    "trout",
    "turkey",
    "turtle",
    "viper",
    "vulture",
    "wallaby",
    "walrus",
    "wasp",
    "weasel",
    "whale",
    "wildcat",
    "wolf",
    "wolverine",
    "wombat",
    "woodcock",
    "woodpecker",
    "worm",
    "wren",
    "yak",
    "zebra",
]
